"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isRunningInVehicleServices = exports.androidNativeHelpers = void 0;
const triggerAndroid_1 = require("../util/triggerAndroid");
const isRunningInVehicleServices = (() => {
    try {
        //@ts-ignore
        const android = Android;
        return (android !== undefined);
    }
    catch {
        return false;
    }
})();
exports.isRunningInVehicleServices = isRunningInVehicleServices;
/**
 *
 * This is a helper method which triggers the 'triggerAndroid' method.
 * This method allows you to pass serializable data to the arguments whereas triggerAndroid only accepts primitives.
 * @ignore
 * @param insideVs boolean for if you are in VehicleServices or not
 */
const androidNativeHelpers = (insideVs) => ({
    sendNotification: (notification) => {
        if (insideVs) {
            try {
                const arg = JSON.stringify(notification);
                (0, triggerAndroid_1.triggerAndroid)("sendNotification", arg);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    apiReady: () => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("apiReady");
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    setItem: (key, value) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("setItem", key, value);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    getItem: (key) => {
        if (insideVs) {
            try {
                return (0, triggerAndroid_1.triggerAndroid)("getItem", key);
            }
            catch (e) {
                console.error(e);
            }
        }
        return null;
    },
    deleteItem: (key) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("deleteItem", key);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    clearItems: () => {
        if (insideVs) {
            try {
                console.log('this called');
                (0, triggerAndroid_1.triggerAndroid)("clearItems");
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    setHospital: (id) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("setHospital", id);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    setPriority: (id) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("setPriority", id);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    setNavLayerPoint: (id, layerData) => {
        if (insideVs) {
            try {
                const arg = JSON.stringify(layerData);
                (0, triggerAndroid_1.triggerAndroid)("setNavLayerPoint", id, arg);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    setNavLayerShape: (id, layerData) => {
        if (insideVs) {
            try {
                const arg = JSON.stringify(layerData);
                (0, triggerAndroid_1.triggerAndroid)("setNavLayerShape", id, arg);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    deleteNavLayer: (id) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("deleteNavLayer", id);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    sendRawRakelAction: (rawRakelAction) => {
        if (insideVs) {
            try {
                const data = JSON.stringify(rawRakelAction);
                (0, triggerAndroid_1.triggerAndroid)("sendRawRakelAction", data);
            }
            catch (e) {
                console.error(e);
            }
        }
    }
});
exports.androidNativeHelpers = androidNativeHelpers;
//# sourceMappingURL=AndroidNativeHelpers.js.map