"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_2 = require("@chakra-ui/react");
const lodash_1 = __importDefault(require("lodash"));
const EventHelpers_1 = require("../../../util/EventHelpers");
const components_1 = require("../../../components");
const domain_1 = require("../../../../domain");
const LastNotificationComponent = ({ lastingNotification, onTrigger, onRemove }) => {
    return (0, jsx_runtime_1.jsxs)(react_2.Modal, { closeOnOverlayClick: false, closeOnEsc: false, isOpen: true, isCentered: true, onClose: () => {
        }, children: [(0, jsx_runtime_1.jsx)(react_2.ModalOverlay, {}), (0, jsx_runtime_1.jsx)(react_2.ModalContent, { children: (0, jsx_runtime_1.jsx)(components_1.NotificationComponent, { notification: lastingNotification, onTrigger: onTrigger, onRemove: onRemove }) })] });
};
const NotificationProvider = ({ children }) => {
    const [notifications, setNotifications] = (0, react_1.useState)([]);
    (0, react_1.useEffect)(() => {
        const subscriptionFunctionSendNotification = (e) => {
            //get the notification which has been sent
            const notification = (e.detail);
            //clone the current notifications (as to not risk mutating state)
            const newNotifications = lodash_1.default.clone(notifications);
            //push the new notification to the array
            newNotifications.push(notification);
            //set the new notifications and rerender
            setNotifications(newNotifications);
        };
        (0, EventHelpers_1.subscribe)(domain_1.EvamEvent.VehicleServicesNotificationSent, subscriptionFunctionSendNotification);
        return () => {
            (0, EventHelpers_1.unsubscribe)(domain_1.EvamEvent.VehicleServicesNotificationSent, subscriptionFunctionSendNotification);
        };
    }, [notifications, setNotifications]);
    const dispatchCallback = (0, react_1.useCallback)((uuid) => {
        (0, EventHelpers_1.publish)(domain_1.EvamEvent.VehicleServicesNotificationCallbackTriggered, uuid);
        const notificationsClone = lodash_1.default.clone(notifications);
        const notificationToRemove = notificationsClone.find((notification) => {
            return (uuid === notification.primaryButton.callback || (notification.secondaryButton !== undefined && uuid === notification.secondaryButton.callback));
        });
        if (notificationToRemove !== undefined) {
            const indexOfNotificationToRemove = notificationsClone.indexOf(notificationToRemove);
            if (indexOfNotificationToRemove !== undefined) {
                notificationsClone.splice(indexOfNotificationToRemove, 1);
                setNotifications(notificationsClone);
            }
        }
    }, [notifications]);
    const removeNotification = (0, react_1.useCallback)((notification) => {
        const notificationsClone = lodash_1.default.clone(notifications);
        const notificationIndex = notificationsClone.indexOf(notification);
        if (notificationIndex !== undefined) {
            notificationsClone.splice(notificationIndex, 1);
            setNotifications(notificationsClone);
        }
    }, [notifications]);
    const actionNotifications = (0, react_1.useMemo)(() => notifications.filter(({ notificationType }) => notificationType !== domain_1.NotificationType.LASTING_HUN, [notifications]), [notifications]);
    const lastingNotification = (0, react_1.useMemo)(() => notifications.find(({ notificationType }) => notificationType === domain_1.NotificationType.LASTING_HUN), [notifications]);
    const changeLastingNotificationToAction = (0, react_1.useCallback)((lastingNotification) => {
        const notification = notifications.find((notificationToQuery) => lastingNotification === notificationToQuery);
        if (notification !== undefined) {
            const newNotifications = notifications.filter((notificationToFilter) => notificationToFilter !== notification);
            newNotifications.push({
                ...notification,
                notificationType: domain_1.NotificationType.ACTION_HUN
            });
            setNotifications(newNotifications);
        }
    }, [notifications]);
    return ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsxs)(components_1.VehicleServicesNoRender, { children: [lastingNotification !== undefined ?
                        (0, jsx_runtime_1.jsx)(LastNotificationComponent, { lastingNotification: lastingNotification, onRemove: changeLastingNotificationToAction, onTrigger: dispatchCallback }) : null, (0, jsx_runtime_1.jsx)(react_2.Box, { w: "100vw", h: "100vh", position: "absolute", children: (0, jsx_runtime_1.jsx)(react_2.VStack, { left: "1%", bottom: "1%", position: "inherit", children: actionNotifications.map((notification, index) => ((0, jsx_runtime_1.jsx)(react_2.SlideFade, { in: true, offsetY: "20px", children: (0, jsx_runtime_1.jsx)(components_1.NotificationComponent, { notification: notification, onTrigger: dispatchCallback, onRemove: removeNotification }) }, index))) }) })] }), children] }));
};
exports.default = NotificationProvider;
//# sourceMappingURL=NotificationProvider.js.map