declare enum BatteryHealth {
    UNKNOWN = "UNKNOWN",
    GOOD = "GOOD",
    OVERHEAT = "OVERHEAT",
    DEAD = "DEAD",
    OVER_VOLTAGE = "OVER_VOLTAGE",
    UNSPECIFIED_FAILURE = "UNSPECIFIED_FAILURE ",
    COLD = "COLD"
}
declare enum BatteryPlugged {
    DOCK = "DOCK",
    AC = "AC",
    USB = "USB",
    WIRELESS = "WIRELESS"
}
declare enum BatteryStatus {
    UNKNOWN = "UNKNOWN",
    CHARGING = "CHARGING",
    DISCHARGING = "DISCHARGING",
    NOT_CHARGING = "NOT_CHARGING",
    FULL = "FULL"
}
declare class Battery {
    health?: BatteryHealth | undefined;
    plugged?: BatteryPlugged | undefined;
    status?: BatteryStatus | undefined;
    capacity?: number | undefined;
    /**
     *  Class representing the device's battery health, status and plugged state.
     *  See https://developer.android.com/reference/android/os/BatteryManager for more information.
     * @param health the battery's health (either UNKNOWN, GOOD, OVERHEAT, DEAD, OVER_VOLTAGE, UNSPECIFIED_FAILURE, COLD)
     * @param plugged the battery's plugged status (either DOCK, AC, USB, WIRELESS)
     * @param status the battery's status (either UNKNOWN, CHARGING, DISCHARGING, NOT_CHARGING, FULL)
     * @param capacity Remaining battery capacity as an integer percentage of total capacity (with no fractional part).
     */
    constructor(health?: BatteryHealth | undefined, plugged?: BatteryPlugged | undefined, status?: BatteryStatus | undefined, capacity?: number | undefined);
    /**
     * Create from JSON
     * @param battery JSON object
     */
    static fromJSON(battery: any): Battery;
}
export { BatteryHealth, BatteryPlugged, BatteryStatus, Battery };
