"use strict";
/**
 * data class LeavePatientLocation(
 *     override val locationType: LocationType = LocationType.LeavePatientSite,
 *     override val locationId: String,
 *     override val latitude: Double,
 *     override val longitude: Double,
 *     override val street: String?,
 *     override val locality: String?,
 *     override val municipality: String?,
 *     override val routeDirections: String?,
 *     val leaveTime: LocalDateTime?,
 * )
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.LeavePatientLocation = void 0;
/* istanbul ignore next */
class LeavePatientLocation {
    /**
     * Location of a leave patient location
     * @param latitude Latitude in decimal degrees
     * @param longitude Longitude in decimal degrees
     * @param street The street name if available
     * @param locality The locality name if available
     * @param municipality The municipality name if available
     * @param routeDirections The route directions text if available
     * @param leaveTime the leave time of the patient
     */
    constructor(latitude, longitude, street, locality, municipality, routeDirections, leaveTime) {
        this.latitude = latitude;
        this.longitude = longitude;
        this.street = street;
        this.locality = locality;
        this.municipality = municipality;
        this.routeDirections = routeDirections;
        this.leaveTime = leaveTime;
    }
    /**
     * Create from JSON
     * @param loc JSON object
     */
    static fromJSON(loc) {
        if (loc.latitude === undefined || loc.longitude === undefined) {
            throw Error("latitude, longitude must be defined for DestinationSiteLocation");
        }
        return new LeavePatientLocation(loc.latitude, loc.longitude, loc.street, loc.locality, loc.municipality, loc.routeDirections, loc.leaveTime);
    }
}
exports.LeavePatientLocation = LeavePatientLocation;
//# sourceMappingURL=LeavePatientLocation.js.map